@@ -72,7 +72,8 @@ def import_env_variables(environment):
         else:
             env_vars.append(
                 Environment(
-                    Name=key, Value=define_string_interpolation(environment[key])
+                    Name=key,
+                    Value=define_string_interpolation(environment[key]),
                 )
             )
     return env_vars
@@ -100,7 +101,7 @@ def extend_container_secrets(container, secret):
 
 
 def extend_container_envvars(container, env_vars):
-    ignored_containers = ["xray-daemon", "envoy"]
+    ignored_containers = ["xray-daemon", "envoy", "cw_agent"]
     if (
         isinstance(container, ContainerDefinition)
         and not isinstance(container.Name, (Ref, Sub, GetAtt, ImportValue, FindInMap))
