@@ -334,13 +334,18 @@ def evaluate_docker_configs(settings):
             if not keyisset("x-docker_opts", service.definition):
                 continue
             docker_config = service.definition["x-docker_opts"]
-            if keyisset("InterpolateWithDigest", docker_config):
-                if not invalidate_image_from_ecr(service, mute=True):
-                    LOG.warn(
-                        "You set InterpolateWithDigest to true for x-docker for an image in AWS ECR."
-                        "Please refer to x-ecr"
+            if SCANS_POSSIBLE:
+                if keyisset("InterpolateWithDigest", docker_config):
+                    if not invalidate_image_from_ecr(service, mute=True):
+                        LOG.warn(
+                            "You set InterpolateWithDigest to true for x-docker for an image in AWS ECR."
+                            "Please refer to x-ecr"
+                        )
+                        continue
+                else:
+                    warnings.warn(
+                        "Run pip install ecs_composex[ecrscan] to use x-ecr features"
                     )
-                    continue
                 service.retrieve_image_digest()
                 if service.image_digest:
                     service.image = image_tag_re.sub(
@@ -405,7 +410,7 @@ def generate_full_template(settings):
     vpc_stack = add_vpc_to_root(root_stack, settings)
     settings.set_networks(vpc_stack, root_stack)
     dns_settings = DnsSettings(root_stack, settings, get_vpc_id(vpc_stack))
-    settings.ecs_cluster = add_ecs_cluster(root_stack, settings)
+    add_ecs_cluster(root_stack, settings)
     associate_services_to_root_stack(root_stack, settings, vpc_stack)
     if keyisset(ACM_KEY, settings.compose_content):
         init_acm_certs(settings, dns_settings, root_stack)
@@ -435,4 +440,6 @@ def generate_full_template(settings):
     if keyisset("x-dashboards", settings.compose_content):
         DashboardsStack("dashboards", settings)
     add_all_tags(root_stack.stack_template, settings)
+    for family in settings.families.values():
+        family.validate_compute_configuration_for_task(settings)
     return root_stack
