@@ -6,12 +6,21 @@
 Module to control S3 stack
 """
 
+from compose_x_common.compose_x_common import keyisset
 from troposphere import MAX_OUTPUTS, GetAtt, Ref
 
 from ecs_composex.common import build_template
-from ecs_composex.common.compose_resources import XResource, set_resources
+from ecs_composex.common.compose_resources import (
+    XResource,
+    set_lookup_resources,
+    set_new_resources,
+    set_resources,
+    set_use_resources,
+)
 from ecs_composex.common.stacks import ComposeXStack
+from ecs_composex.s3.s3_ecs import define_bucket_mappings
 from ecs_composex.s3.s3_params import (
+    MAPPINGS_KEY,
     MOD_KEY,
     RES_KEY,
     S3_BUCKET_ARN,
@@ -27,7 +36,6 @@ def create_s3_template(new_buckets, template):
     """
     Function to create the root S3 template.
 
-    :param ecs_composex.common.settings.ComposeXSettings settings:
     :param list new_buckets:
     :param troposphere.Template template:
     :return:
@@ -87,20 +95,24 @@ class XStack(ComposeXStack):
     """
 
     def __init__(self, title, settings, **kwargs):
-        set_resources(settings, Bucket, RES_KEY, MOD_KEY)
-        new_buckets = [
-            bucket
-            for bucket in settings.compose_content[RES_KEY].values()
-            if not bucket.lookup and not bucket.use
-        ]
-        if new_buckets:
+        set_resources(settings, Bucket, RES_KEY, MOD_KEY, mapping_key=MAPPINGS_KEY)
+        x_resources = settings.compose_content[RES_KEY].values()
+        new_resources = set_new_resources(x_resources, RES_KEY, True)
+        lookup_resources = set_lookup_resources(x_resources, RES_KEY)
+        use_resources = set_use_resources(x_resources, RES_KEY, True)
+        if new_resources:
             stack_template = build_template(
                 f"S3 root by ECS ComposeX for {settings.name}"
             )
             super().__init__(title, stack_template, **kwargs)
-            create_s3_template(new_buckets, stack_template)
+            create_s3_template(new_resources, stack_template)
         else:
             self.is_void = True
-
+        if lookup_resources or use_resources:
+            if not keyisset(RES_KEY, settings.mappings):
+                settings.mappings[RES_KEY] = {}
+            define_bucket_mappings(
+                settings.mappings[RES_KEY], lookup_resources, use_resources, settings
+            )
         for resource in settings.compose_content[RES_KEY].values():
             resource.stack = self
